{% if anexos %}
    <div class="especial" style="width: 96%; margin-top: 10px; padding-bottom: 5px;">
        <table>
            {% for anexo in anexos %}
            <tr>
                <td class="celda-i" style="width: 30px; padding: 0; vertical-align: top;">
                    <label style="padding-top: 8px; margin: 0; font-weight: bold;" for="anexo{{ forloop.counter }}">
                        {{ forloop.counter }}.
                    </label>
                </td>
                <td class="celda-c" style="width: 100%; padding-left: 10px;">
                    <input 
                        style="min-height: 25px; width: 100%; background: white; border: none; border-bottom: 1px solid #002857; border-radius: 0; padding: 5px 0;" 
                        type="text" 
                        id="anexo{{ forloop.counter }}" 
                        name="anexo{{ forloop.counter }}" 
                        value="{{ anexo.nombre }}{% if anexo.fecha_carga %} - {{ anexo.fecha_carga }}{% endif %}" 
                        readonly>
                </td>
            </tr>
            {% endfor %}
        </table>
    </div>
{% else %}
    <div class="especial" style="width: 96%; margin-top: 10px; padding-bottom: 5px;">
        <table>
            <tr>
                <td class="celda-c" style="width: 100%; padding-left: 10px;">
                    <input 
                        style="min-height: 25px; width: 100%; background: white; border: none; border-bottom: 1px solid #002857; border-radius: 0; padding: 5px 0;" 
                        type="text" 
                        value="No se encontraron documentos adjuntos" 
                        readonly>
                </td>
            </tr>
        </table>
    </div>
{% endif %}